@@ -10,7 +10,7 @@ from trytond.model.exceptions import AccessError
 from trytond.pool import Pool, PoolMeta
 from trytond.transaction import Transaction
 
-__all__ = ['Move']
+from trytond.modules.product import round_price
 
 
 class Move(metaclass=PoolMeta):
@@ -81,15 +81,13 @@ class Move(metaclass=PoolMeta):
         to_save = []
         for move, move_qty in fifo_moves:
             consumed_qty += move_qty
-            if move.from_location.type in {'supplier', 'production'}:
-                with Transaction().set_context(date=move.effective_date):
-                    move_unit_price = Currency.compute(
-                        move.currency, move.unit_price,
-                        self.company.currency, round=False)
-                move_unit_price = Uom.compute_price(
-                    move.uom, move_unit_price, move.product.default_uom)
-            else:
-                move_unit_price = move.cost_price or 0
+
+            with Transaction().set_context(date=move.effective_date):
+                move_unit_price = Currency.compute(
+                    move.currency, move.unit_price,
+                    self.company.currency, round=False)
+            move_unit_price = Uom.compute_price(move.uom, move_unit_price,
+                    move.product.default_uom)
             cost_price += move_unit_price * Decimal(str(move_qty))
 
             move_qty = Uom.compute_qty(self.product.default_uom, move_qty,
@@ -114,9 +112,7 @@ class Move(metaclass=PoolMeta):
         self.unit_price = unit_price
 
         if cost_price:
-            digits = self.__class__.cost_price.digits
-            cost_price = cost_price.quantize(
-                Decimal(str(10.0 ** -digits[1])))
+            cost_price = round_price(cost_price)
         else:
             cost_price = average_cost_price
         return cost_price, average_cost_price
@@ -157,12 +153,3 @@ class Move(metaclass=PoolMeta):
                 gettext('product_cost_fifo.msg_move_delete_fifo',
                     move=fifo_moves[0].rec_name))
         super(Move, cls).delete(moves)
-
-    @classmethod
-    def copy(cls, moves, default=None):
-        if default is None:
-            default = {}
-        else:
-            default = default.copy()
-        default.setdefault('fifo_quantity', cls.default_fifo_quantity())
-        return super().copy(moves, default=default)
